ImmSurv This function plots two variables on a scatter plot and contextualises the plot using survival time.
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 | ImmSurv(
Data,
ID = "ID",
Status = "Status",
Survival = "Survival",
Stage = "Stage",
SurvivalGroups = "Groups",
Marker = "Marker",
Genes,
Genez,
Axes = "Axes",
Variable1 = "Variable1",
Variable1Unit = "Variable1Unit",
Variable2 = "Variable2",
Variable2Unit = "Variable2Unit"
)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.